@@ -1,3 +1,3 @@
 from .cortx_jupyter import CortxJupyter
 from .cortx_authenticator import CortxAuthenticator
-from .cortx_file_manager import read_data, write_data, write_model
\ No newline at end of file
+from .cortx_file_manager import read_data, write_data, write_model, read_model
\ No newline at end of file
