@@ -6,7 +6,8 @@ import pandas as pd
 import numpy as np
 
 config_file_path = "credentials.json" 
-from keras.models import model_from_json
+# from keras.models import model_from_json
+from tensorflow.keras.models import model_from_json
 
 
 def _config():
